/v1/projects/{project_id}/dynamips/vms/{vm_id} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/projects/{project_id}/dynamips/vms/{vm_id}

Contents

- /v1/projects/{project_id}/dynamips/vms/{vm_id}
  - GET /v1/projects/{project_id}/dynamips/vms/{vm_id}
    - Parameters
    - Response status codes
    - Output
  - PUT /v1/projects/{project_id}/dynamips/vms/{vm_id}
    - Parameters
    - Response status codes
    - Input
    - Output
  - DELETE /v1/projects/{project_id}/dynamips/vms/{vm_id}
    - Parameters
    - Response status codes

## GET /v1/projects/{project_id}/dynamips/vms/{vm_id}

Get a Dynamips VM instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 200: Success
- 400: Invalid request
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
aux |  | integer | auxiliary console TCP port
chassis |  | string | router chassis model
clock_divisor |  | integer | clock divisor
confreg |  | string | configuration register
console |  | integer | console TCP port
disk0 |  | integer | disk0 size in MB
disk1 |  | integer | disk1 size in MB
dynamips_id | ✔ | integer | ID to use with Dynamips
exec_area |  | integer | exec area value
idlemax |  | integer | idlemax value
idlepc |  | string | Idle-PC value
idlesleep |  | integer | idlesleep value
image |  | string | path to the IOS image
iomem |  | integer | I/O memory percentage
mac_addr |  | string | base MAC address
midplane |  | enum | Possible values: std, vxr
mmap |  | boolean | MMAP feature
name | ✔ | string | Dynamips VM instance name
npe |  | enum | Possible values: npe-100, npe-150, npe-175, npe-200, npe-225, npe-300, npe-400, npe-g2
nvram |  | integer | amount of NVRAM in KB
platform |  | string | platform
power_supplies |  | array | Power supplies status
private_config |  | string | path to the IOS private configuration file
private_config_base64 |  | string | private configuration base64 encoded
project_id | ✔ | string | Project UUID
ram |  | integer | amount of RAM in MB
sensors |  | array | Temperature sensors
slot0 |  |  | Network module slot 0
slot1 |  |  | Network module slot 1
slot2 |  |  | Network module slot 2
slot3 |  |  | Network module slot 3
slot4 |  |  | Network module slot 4
slot5 |  |  | Network module slot 5
slot6 |  |  | Network module slot 6
sparsemem |  | boolean | sparse memory feature
startup_config |  | string | path to the IOS startup configuration file
startup_config_base64 |  | string | startup configuration base64 encoded
system_id |  | string | system ID
vm_id | ✔ | string | Dynamips router instance UUID
wic0 |  |  | Network module WIC slot 0
wic1 |  |  | Network module WIC slot 0
wic2 |  |  | Network module WIC slot 0

## PUT /v1/projects/{project_id}/dynamips/vms/{vm_id}

Update a Dynamips VM instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 200: Instance updated
- 400: Invalid request
- 404: Instance doesn’t exist
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
aux |  | integer | auxiliary console TCP port
chassis |  | string | router chassis model
clock_divisor |  | integer | clock divisor
confreg |  | string | configuration register
console |  | integer | console TCP port
disk0 |  | integer | disk0 size in MB
disk1 |  | integer | disk1 size in MB
exec_area |  | integer | exec area value
idlemax |  | integer | idlemax value
idlepc |  | string | Idle-PC value
idlesleep |  | integer | idlesleep value
image |  | string | path to the IOS image
iomem |  | integer | I/O memory percentage
mac_addr |  | string | base MAC address
midplane |  | enum | Possible values: std, vxr
mmap |  | boolean | MMAP feature
name |  | string | Dynamips VM instance name
npe |  | enum | Possible values: npe-100, npe-150, npe-175, npe-200, npe-225, npe-300, npe-400, npe-g2
nvram |  | integer | amount of NVRAM in KB
platform |  | string | platform
power_supplies |  | array | Power supplies status
private_config |  | string | path to the IOS private configuration file
private_config_base64 |  | string | private configuration base64 encoded
ram |  | integer | amount of RAM in MB
sensors |  | array | Temperature sensors
slot0 |  |  | Network module slot 0
slot1 |  |  | Network module slot 1
slot2 |  |  | Network module slot 2
slot3 |  |  | Network module slot 3
slot4 |  |  | Network module slot 4
slot5 |  |  | Network module slot 5
slot6 |  |  | Network module slot 6
sparsemem |  | boolean | sparse memory feature
startup_config |  | string | path to the IOS startup configuration file
startup_config_base64 |  | string | startup configuration base64 encoded
system_id |  | string | system ID
wic0 |  |  | Network module WIC slot 0
wic1 |  |  | Network module WIC slot 0
wic2 |  |  | Network module WIC slot 0

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
aux |  | integer | auxiliary console TCP port
chassis |  | string | router chassis model
clock_divisor |  | integer | clock divisor
confreg |  | string | configuration register
console |  | integer | console TCP port
disk0 |  | integer | disk0 size in MB
disk1 |  | integer | disk1 size in MB
dynamips_id | ✔ | integer | ID to use with Dynamips
exec_area |  | integer | exec area value
idlemax |  | integer | idlemax value
idlepc |  | string | Idle-PC value
idlesleep |  | integer | idlesleep value
image |  | string | path to the IOS image
iomem |  | integer | I/O memory percentage
mac_addr |  | string | base MAC address
midplane |  | enum | Possible values: std, vxr
mmap |  | boolean | MMAP feature
name | ✔ | string | Dynamips VM instance name
npe |  | enum | Possible values: npe-100, npe-150, npe-175, npe-200, npe-225, npe-300, npe-400, npe-g2
nvram |  | integer | amount of NVRAM in KB
platform |  | string | platform
power_supplies |  | array | Power supplies status
private_config |  | string | path to the IOS private configuration file
private_config_base64 |  | string | private configuration base64 encoded
project_id | ✔ | string | Project UUID
ram |  | integer | amount of RAM in MB
sensors |  | array | Temperature sensors
slot0 |  |  | Network module slot 0
slot1 |  |  | Network module slot 1
slot2 |  |  | Network module slot 2
slot3 |  |  | Network module slot 3
slot4 |  |  | Network module slot 4
slot5 |  |  | Network module slot 5
slot6 |  |  | Network module slot 6
sparsemem |  | boolean | sparse memory feature
startup_config |  | string | path to the IOS startup configuration file
startup_config_base64 |  | string | startup configuration base64 encoded
system_id |  | string | system ID
vm_id | ✔ | string | Dynamips router instance UUID
wic0 |  |  | Network module WIC slot 0
wic1 |  |  | Network module WIC slot 0
wic2 |  |  | Network module WIC slot 0

## DELETE /v1/projects/{project_id}/dynamips/vms/{vm_id}

Delete a Dynamips VM instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »